@@ -1,3 +1,5 @@
+"""Parse and execute Pythonect code"""
+
 # Version
 
 try:
@@ -8,7 +10,7 @@ try:
 
     del _version
 
-except ImportError, e:
+except ImportError as e:
 
     from internal.version import get_version
 
@@ -23,9 +25,9 @@ except ImportError, e:
 
 try:
 
-    from internal.eval import eval, split
+    from internal.eval import eval, parse
 
-except ImportError, e:
+except ImportError as e:
 
     # When imported by setup.py, it's expected that not all the dependencies will be there
 
